@@ -1,9 +1,16 @@
+import sys
+
+import netsquid as ns
 from application import AliceProgram, BobProgram
 
 from squidasm.run.stack.config import StackNetworkConfig
 from squidasm.run.stack.run import run
 from squidasm.sim.stack.common import LogManager
 
+# Fix seed on test runs to avoid accidentally triggering the "error" in this example
+if "--test_run" in sys.argv:
+    ns.set_random_state(seed=42)
+
 # import network configuration from file
 cfg = StackNetworkConfig.from_file("config.yaml")
 
